@@ -13,6 +13,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/
  - 更新履歴：
+ -      [2007/08/05] 挿入又は更新操作の実行manip()関数を追加
  -      [2007/03/11] 入力データのエスケープ処理をRKT_validateへ移行
  -      [2006/05/19] privateの関数をpublickに変更（query関連）
  -      [2005/06/01] コンストラクタ引数変更、DB接続オジェクトを追加
@@ -500,6 +501,27 @@ class RKT_manip extends RKT_validate
         }
     }
 
+    /**
+     * 挿入又は更新操作の実行
+     *
+     * @access public
+     * @return integer 影響を与えたテーブル行数
+     */
+    function manip()
+    {        
+        /* 入力データへの加工処理 */
+        $this->inputEffect();
+
+        /* 更新・挿入処理 */
+        if (empty($this->cur_id)){
+            $result = $this->insertQuery();
+        } else {
+            $result = $this->updateQuery();
+        }
+
+        return $result;
+    }
+
     /**
      * 操作の実行
      *
