@@ -304,7 +304,7 @@ class webapp extends WAP_private
         }
         $value = array(
             'modify'=> $this->objmnp->getValue('modify'),
-            'regist_date'=> $this->objmnp->getValue('regist_date'),
+            'regist_date'=> date('Y-m-d H:i:s'),
             'ref_account'=> $this->objmnp->getValue('ref_to'),
             'ref_to'=> $this->objmnp->getValue('ref_to'),
             'ref_from'=> $this->objmnp->getValue('ref_from'),
