@@ -63,15 +63,15 @@ class webapp extends WAP_public
         if ($objauth->autoLoginUserAgentID()){
             $this->update_last_login();
             $this->sid = RKT_auth::getSessionID();
-            header('Location: '.HTTP_ACTION.'private/home/menu/'.$this->sid.'/');
-            $this->print_url(HTTP_ACTION.'private/home/menu/'.$this->sid.'/');
+            header('Location: '.HTTP_ACTION.'private/home/home/'.$this->sid.'/');
+            $this->print_url(HTTP_ACTION.'private/home/home/'.$this->sid.'/');
             exit();
         }
         
         if ($this->account['status'] != WAP_ACC_GUEST){
             $this->update_last_login();
-            header('Location: '.HTTP_ACTION.'private/home/menu/'.$this->sid.'/');
-            $this->print_url(HTTP_ACTION.'private/home/menu/'.$this->sid.'/');
+            header('Location: '.HTTP_ACTION.'private/home/home/'.$this->sid.'/');
+            $this->print_url(HTTP_ACTION.'private/home/home/'.$this->sid.'/');
             exit();
         }
 
