@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/07] 新規登ファームが表示されないエラーを修正
  -      [2007/01/21] テーブルを fri_friends から fri_invite に変更
  -      [2006/07/10] 作成
  - ======================================================================== */
@@ -75,12 +76,7 @@ class webapp extends WAP_public
         $this->setTemplateFile('public/registry/account.tpl');        
 
         /* PathInfo引数の設定 */
-        $this->setPathInfo('ref_invite');
-        $this->Assign('ref_invite', $this->ref_invite);
-        $this->setPathInfo('seed',1,'string');
-        $this->Assign('seed', $this->seed);
-        $this->setPathInfo('key',2,'string');
-        $this->Assign('key', $this->key);
+        $this->set_pathinfo();
 
         // PathInfo引数が正常に動いているか？
     	if (!$this->check_keyword()){
@@ -97,6 +93,30 @@ class webapp extends WAP_public
         }
     }
 
+    /**
+     * PathInfo引数の設定
+     *
+     * @access private
+     * @return void
+     */
+    function set_pathinfo()
+    {
+        /* PathInfo引数の設定 */
+        $this->setPathInfo('ref_invite');
+        if (empty($this->ref_invite)){
+            $this->setPathInfo('ref_invite',-1);
+            $this->setPathInfo('seed',0,'string');
+            $this->setPathInfo('key',1,'string');
+        } else {
+            $this->setPathInfo('seed',1,'string');
+            $this->setPathInfo('key',2,'string');
+        }
+
+        $this->Assign('ref_invite', $this->ref_invite);
+        $this->Assign('seed', $this->seed);
+        $this->Assign('key', $this->key);
+    }
+
     /**
      * キーワードの確認
      *
