@@ -386,7 +386,8 @@ class webapp extends WAP_friend
             'WHERE '.
                 'id = '.$this->delete .' AND '.
                 'ref_diary = '.$this->ref_diary.' AND '.
-                'ref_entry = '.$this->id;
+                'ref_entry = '.$this->id.' AND '.
+                'ref_account = '.$this->account['id'];
         return $this->objdb->exec($sql);
     }
 
