@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/05] 画像取得順のNoticeを削除
  -      [2007/07/01] 絵文字用ウインドウデザインの追加
  -      [2006/09/30] コメントの誤字を修正
  -      [2006/09/29] 基礎URLの初期値自動入力追加と説明を変更
@@ -495,6 +496,9 @@ class webapp
             'community'=> 'sort',
             'header'=>    'sort',
             'admin'=>     'rsort',
+            'top'=>       'sort',
+            'common'=>    'sort',
+            'public'=>    'sort',
         );
 
         $dir = THEME_DIR.$id.DIRECTORY_SEPARATOR;
