@@ -20,6 +20,7 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--	[2007/08/05] レビューの対象商品の必須項目を緩和
 --      [2007/07/05] 日記設定：sns_dia_diary.visibilityを削除
 --      [2007/06/17] コミュニティ：トピック、イベント、記事、アンケート権限追加
 --      [2007/06/17] コミュニティ：アクセス、足跡追加
@@ -1093,15 +1094,15 @@ CREATE TABLE `sns_rev_item` (
   `post` int(11) default '0',
   `url` varchar(255) NOT NULL,
   `asin` varchar(128) NOT NULL,
-  `name` text NOT NULL,
-  `creator` text NOT NULL,
-  `release` varchar(32) NOT NULL,
-  `manufacturer` varchar(255) NOT NULL,
-  `imagesmall` varchar(255) NOT NULL,
-  `imagemedium` varchar(255) NOT NULL,
-  `imagelarge` varchar(255) NOT NULL,
-  `listprice` varchar(64) NOT NULL,
-  `ourprice` varchar(64) NOT NULL,
+  `name` text,
+  `creator` text,
+  `release` varchar(32),
+  `manufacturer` varchar(255),
+  `imagesmall` varchar(255),
+  `imagemedium` varchar(255),
+  `imagelarge` varchar(255),
+  `listprice` varchar(64),
+  `ourprice` varchar(64),
   PRIMARY KEY  (`id`),
   UNIQUE (`asin`)
 ) TYPE=MyISAM AUTO_INCREMENT=1;
